The HentaiVerse

23621
1498
1218
133
Battle Time
Choose from the Battle Actions highlighted above, and use them to defeat your enemies listed to the right. When all enemies are reduced to zero Health, you win. If your Health reaches zero, you are defeated.

Your spike shield hits The Failure Being for 5 points of fire damage.
The Failure Being gains the effect Stunned.
You counter The Failure Being for 6124 points of void damage.
You block the attack from The Failure Being.
You gain the effect Absorbing Ward.
You cast Absorb.

Flee
Scan
Shield Bash | Vital Strike | Merciful Blow

Fiery Blast | Inferno
Freeze | Blizzard
Shockblast | Chained Lightning
Gale | Downburst
Smite | Banishment
Corruption | Disintegrate
Drain | Weaken | Imperil
Slow | Sleep | Confuse
Blind | Silence | MagNet
Cure | Regen | Full-Cure
Protection | Haste | Shadow Veil
Absorb | Spark of Life | Spirit Shield
Heartseeker | Arcane Focus

P
Spirit Gem
1
Health Draught
2
Health Potion
3
Health Elixir
4
Mana Draught
5
Mana Potion
6
Mana Elixir
7
Spirit Draught
8
Spirit Potion
9
Spirit Elixir
10
11
12
13
14
15
S1
S2
S3
S4
S5
S6
N1
N2
N3
N4
N5
N6
369
Hansen Yang
369
Dude Just Stop Jerking
369
Mikuru Asahina
369
The Failure Being